@@ -34,7 +34,7 @@ NULL
 #'
 #' Launch the memery example app in your browser.
 #'
-#' This example app launches with animated gif support and relevant initial example gif if the magick package and ImageMagick software are installed on the user's system.
+#' This example app launches with animated gif support and relevant initial example gif if the magick package is installed.
 #' Otherwise, a simplified version of the app that does not provide gif support launches and starting images must be jpg or png.
 #'
 #' Due to how \code{meme_gif} works, gifs will not display in a hosted app, i.e., on \code{shinyapps.io}.
@@ -58,7 +58,7 @@ memeApp <- function(){
   shiny::runApp(system.file("shiny", "memeApp", package = "memery"))
 }
 
-.no_magick <- "The `magick` package and the ImageMagick software must be installed to use `meme_gif`."
+.no_magick <- "The `magick` package must be installed to use `meme_gif`."
 
 .check_for_magick <- function(){
   "magick" %in% utils::installed.packages()
